import type { CreateRunner } from '../models/CreateRunner';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { ResponseRunner } from '../models/ResponseRunner';
import type { RunnerGroupNeededError } from '../models/RunnerGroupNeededError';
import type { RunnerGroupNotFoundError } from '../models/RunnerGroupNotFoundError';
import type { UpdateRunner } from '../models/UpdateRunner';
export declare class RunnerService {
    /**
     * Get all
     * Lists all runners.
     * @result ResponseRunner
     * @throws ApiError
     */
    static runnerControllerGetAll(): Promise<Array<ResponseRunner>>;
    /**
     * Post
     * Create a new runner object (id will be generated automagicly).
     * @param requestBody CreateRunner
     * @result any
     * @throws ApiError
     */
    static runnerControllerPost(requestBody?: CreateRunner): Promise<(ResponseRunner | RunnerGroupNeededError | RunnerGroupNotFoundError)>;
    /**
     * Get one
     * Returns a runner of a specified id (if it exists)
     * @param id
     * @result ResponseRunner
     * @throws ApiError
     */
    static runnerControllerGetOne(id: number): Promise<ResponseRunner>;
    /**
     * Put
     * Update a runner object (id can't be changed).
     * @param id
     * @param requestBody UpdateRunner
     * @result ResponseRunner
     * @throws ApiError
     */
    static runnerControllerPut(id: number, requestBody?: UpdateRunner): Promise<ResponseRunner>;
    /**
     * Remove
     * Delete a specified runner (if it exists).
     * @param id
     * @param force
     * @result ResponseRunner
     * @result ResponseEmpty
     * @throws ApiError
     */
    static runnerControllerRemove(id: number, force?: boolean): Promise<ResponseRunner | ResponseEmpty>;
}
