"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunnerTeamService = void 0;
const request_1 = require("../core/request");
class RunnerTeamService {
    /**
     * Get all
     * Lists all runnerTeams.
     * @result ResponseRunnerTeam
     * @throws ApiError
     */
    static async runnerTeamControllerGetAll() {
        const result = await request_1.request({
            method: 'GET',
            path: `/api/teams`,
        });
        return result.body;
    }
    /**
     * Post
     * Create a new runnerTeam object (id will be generated automagicly).
     * @param requestBody CreateRunnerTeam
     * @result ResponseRunnerTeam
     * @throws ApiError
     */
    static async runnerTeamControllerPost(requestBody) {
        const result = await request_1.request({
            method: 'POST',
            path: `/api/teams`,
            body: requestBody,
        });
        return result.body;
    }
    /**
     * Get one
     * Returns a runnerTeam of a specified id (if it exists)
     * @param id
     * @result ResponseRunnerTeam
     * @throws ApiError
     */
    static async runnerTeamControllerGetOne(id) {
        const result = await request_1.request({
            method: 'GET',
            path: `/api/teams/${id}`,
        });
        return result.body;
    }
    /**
     * Put
     * Update a runnerTeam object (id can't be changed).
     * @param id
     * @param requestBody UpdateRunnerTeam
     * @result ResponseRunnerTeam
     * @throws ApiError
     */
    static async runnerTeamControllerPut(id, requestBody) {
        const result = await request_1.request({
            method: 'PUT',
            path: `/api/teams/${id}`,
            body: requestBody,
        });
        return result.body;
    }
    /**
     * Remove
     * Delete a specified runnerTeam (if it exists).
     * @param id
     * @param force
     * @result ResponseRunnerTeam
     * @result ResponseEmpty
     * @throws ApiError
     */
    static async runnerTeamControllerRemove(id, force) {
        const result = await request_1.request({
            method: 'DELETE',
            path: `/api/teams/${id}`,
            query: {
                'force': force,
            },
        });
        return result.body;
    }
}
exports.RunnerTeamService = RunnerTeamService;
